SQL Drivers can be found at: These are the executables for connecting to sql server.
https://docs.microsoft.com/en-us/sql/connect/odbc/windows/release-notes-odbc-sql-server-windows?view=sql-server-ver15#previous-releases

Package used to push and pull data from sql server.

Provides helper functions for dealing with excel and csv files.

Provides several ways to connect to sql server due to individual cpu os differences.

Main src code is in tsql_xlsx